.. _mdzhandler:

****************************
MultiDrizzle Reference Table
****************************

This module supports the interpretation of the ``MDRIZTAB`` for
processing as used in the pipeline.

.. moduleauthor:: Warren Hack, Ivo Busko, Christopher Hanley <help@stsci.edu>

.. automodule:: drizzlepac.mdzhandler
   :members:
   :undoc-members:
